@@ -18,6 +18,7 @@ Implementation Notes
 
 * `Adafruit 2.13" Tri-Color eInk Display Breakout <https://www.adafruit.com/product/4947>`_
 * `Adafruit 2.13" Tri-Color eInk Display FeatherWing <https://www.adafruit.com/product/4814>`_
+* `Adafruit 2.13" Mono eInk Display FeatherWing <https://www.adafruit.com/product/4195>`_
 
 
 **Software and Dependencies:**
@@ -29,7 +30,7 @@ Implementation Notes
 
 import displayio
 
-__version__ = "1.0.12"
+__version__ = "1.0.13"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_SSD1680.git"
 
 _START_SEQUENCE = (
@@ -64,6 +65,8 @@ class SSD1680(displayio.EPaperDisplay):
     """
 
     def __init__(self, bus: displayio.Fourwire, **kwargs) -> None:
+        if "colstart" not in kwargs:
+            kwargs["colstart"] = 1
         stop_sequence = bytearray(_STOP_SEQUENCE)
         try:
             bus.reset()
@@ -95,6 +98,5 @@ class SSD1680(displayio.EPaperDisplay):
             set_current_column_command=0x4E,
             set_current_row_command=0x4F,
             refresh_display_command=0x20,
-            colstart=1,
             always_toggle_chip_select=True,
         )
